@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -125,13 +121,13 @@ public class FormatData_kk extends ListResourceBundle {
                "\u0441\u0435\u043d\u0431\u0456",
             };
         final String[] metaValue_DayAbbreviations = new String[] {
-               "\u0416\u0441",
-               "\u0414\u0441",
-               "\u0421\u0441",
-               "\u0421\u0440",
-               "\u0411\u0441",
-               "\u0416\u043c",
-               "\u0421\u0431",
+               "\u0436\u0441",
+               "\u0434\u0441",
+               "\u0441\u0441",
+               "\u0441\u0440",
+               "\u0431\u0441",
+               "\u0436\u043c",
+               "\u0441\u0431",
             };
         final String[] metaValue_DayNarrows = new String[] {
                "\u0416",
@@ -160,6 +156,34 @@ public class FormatData_kk extends ListResourceBundle {
                "III",
                "IV",
             };
+        final String[] metaValue_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+               "\u0442\u04af\u043d \u0436\u0430\u0440\u044b\u043c\u044b",
+               "\u0442\u04af\u0441\u043a\u0456",
+               "\u0442\u0430\u04a3\u0493\u044b",
+               "",
+               "\u0442\u04af\u0441\u0442\u0435\u043d \u043a\u0435\u0439\u0456\u043d\u0433\u0456",
+               "",
+               "\u043a\u0435\u0448\u043a\u0456",
+               "",
+               "\u0442\u04af\u043d\u0433\u0456",
+               "",
+            };
+        final String[] metaValue_narrow_AmPmMarkers = new String[] {
+               "AM",
+               "PM",
+               "\u0442\u04af\u043d\u0433\u0456",
+               "\u0442\u04af\u0441\u043a\u0456",
+               "\u0442\u0430\u04a3\u0493\u044b",
+               "",
+               "\u0442\u04af\u0441\u0442\u0435\u043d \u043a\u0435\u0439\u0456\u043d\u0433\u0456",
+               "",
+               "\u043a\u0435\u0448\u043a\u0456",
+               "",
+               "\u0442\u04af\u043d\u0433\u0456",
+               "",
+            };
         final String[] metaValue_Eras = new String[] {
                "\u0431.\u0437.\u0434.",
                "\u0431.\u0437.",
@@ -182,39 +206,26 @@ public class FormatData_kk extends ListResourceBundle {
                "GGGG dd.MM.y",
                "G dd.MM.y",
             };
-        final String[] metaValue_japanese_narrow_AmPmMarkers = new String[] {
-               "AM",
-               "PM",
-            };
         final String metaValue_calendarname_gregorian = "\u0413\u0440\u0435\u0433\u043e\u0440\u0438\u0430\u043d\u0434\u044b\u049b \u043a\u04af\u043d\u0442\u0456\u0437\u0431\u0435";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "\u0436\u044b\u043b" },
-            { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.DayAbbreviations", metaValue_DayAbbreviations },
-            { "standalone.DayNarrows", metaValue_DayNarrows },
-            { "islamic.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
+            { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
-            { "TimePatterns", metaValue_TimePatterns },
-            { "islamic.DayNarrows", metaValue_DayNarrows },
-            { "field.zone", "\u0443\u0430\u049b\u044b\u0442 \u0431\u0435\u043b\u0434\u0435\u0443\u0456" },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
-            { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "islamic.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
+            { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "timezone.regionFormat.standard", "{0} \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0442\u044b \u0443\u0430\u049b\u044b\u0442\u044b" },
+            { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.japanese", "\u0416\u0430\u043f\u043e\u043d \u043a\u04af\u043d\u0442\u0456\u0437\u0431\u0435\u0441\u0456" },
-            { "Eras", metaValue_Eras },
             { "japanese.MonthNames", metaValue_MonthNames },
-            { "roc.DayNames", metaValue_DayNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "islamic.QuarterNames", metaValue_QuarterNames },
-            { "QuarterNarrows", metaValue_QuarterNarrows },
-            { "standalone.QuarterNarrows", metaValue_QuarterNarrows },
             { "long.Eras",
                 new String[] {
                     "\u0411\u0456\u0437\u0434\u0456\u04a3 \u0437\u0430\u043c\u0430\u043d\u044b\u043c\u044b\u0437\u0493\u0430 \u0434\u0435\u0439\u0456\u043d",
@@ -223,9 +234,7 @@ public class FormatData_kk extends ListResourceBundle {
             },
             { "roc.QuarterNarrows", metaValue_QuarterNarrows },
             { "islamic.DayNames", metaValue_DayNames },
-            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "field.weekday", "\u0430\u043f\u0442\u0430 \u043a\u04af\u043d\u0456" },
             { "buddhist.MonthNames", metaValue_MonthNames },
             { "DateTimePatterns",
                 new String[] {
@@ -235,6 +244,7 @@ public class FormatData_kk extends ListResourceBundle {
                     "{1}, {0}",
                 }
             },
+            { "narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "latn.NumberElements",
                 new String[] {
                     ",",
@@ -248,49 +258,110 @@ public class FormatData_kk extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "\u0441\u0430\u043d\u00a0\u0435\u043c\u0435\u0441",
+                    "",
+                    "",
                 }
             },
             { "MonthNarrows", metaValue_MonthNarrows },
             { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.DayNames", metaValue_DayNames },
             { "field.minute", "\u043c\u0438\u043d\u0443\u0442" },
             { "field.era", "\u0434\u04d9\u0443\u0456\u0440" },
-            { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
             { "field.dayperiod", "\u0410\u041c/\u0420\u041c" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
-            { "japanese.QuarterNames", metaValue_QuarterNames },
-            { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
             { "calendarname.roc", "\u041c\u0438\u043d\u0433\u0443\u043e \u043a\u04af\u043d\u0442\u0456\u0437\u0431\u0435\u0441\u0456" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "field.month", "\u0430\u0439" },
+            { "field.second", "\u0441\u0435\u043a\u0443\u043d\u0434" },
+            { "DayAbbreviations", metaValue_DayAbbreviations },
+            { "DayNarrows", metaValue_DayNarrows },
+            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "calendarname.islamic", "\u0418\u0441\u043b\u0430\u043c \u043a\u04af\u043d\u0442\u0456\u0437\u0431\u0435\u0441\u0456" },
+            { "DayPeriodRules", "midnight:00:00;noon:12:00;night1:21:00-06:00;afternoon1:12:00-18:00;morning1:06:00-12:00;evening1:18:00-21:00" },
+            { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.TimePatterns", metaValue_TimePatterns },
+            { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "timezone.regionFormat", "{0} \u0443\u0430\u049b\u044b\u0442\u044b" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "{one:0' '\u043c\u044b\u04a3 other:0' '\u043c\u044b\u04a3}",
+                    "{one:00' '\u043c\u044b\u04a3 other:00' '\u043c\u044b\u04a3}",
+                    "{one:000' '\u043c\u044b\u04a3 other:000' '\u043c\u044b\u04a3}",
+                    "{one:0' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d other:0' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d}",
+                    "{one:00' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d other:00' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d}",
+                    "{one:000' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d other:000' '\u043c\u0438\u043b\u043b\u0438\u043e\u043d}",
+                    "{one:0' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434 other:0' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434}",
+                    "{one:00' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434 other:00' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434}",
+                    "{one:000' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434 other:000' '\u043c\u0438\u043b\u043b\u0438\u0430\u0440\u0434}",
+                    "{one:0' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d other:0' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d}",
+                    "{one:00' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d other:00' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d}",
+                    "{one:000' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d other:000' '\u0442\u0440\u0438\u043b\u043b\u0438\u043e\u043d}",
+                }
+            },
+            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
+            { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "standalone.QuarterNames", metaValue_QuarterNames },
+            { "japanese.MonthNarrows", metaValue_MonthNarrows },
+            { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "roc.DayAbbreviations", metaValue_DayAbbreviations },
+            { "standalone.DayNarrows", metaValue_DayNarrows },
+            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
+            { "TimePatterns", metaValue_TimePatterns },
+            { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "field.zone", "\u0443\u0430\u049b\u044b\u0442 \u0431\u0435\u043b\u0434\u0435\u0443\u0456" },
+            { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
+            { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "Eras", metaValue_Eras },
+            { "roc.DayNames", metaValue_DayNames },
+            { "islamic.QuarterNames", metaValue_QuarterNames },
+            { "QuarterNarrows", metaValue_QuarterNarrows },
+            { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "standalone.QuarterNarrows", metaValue_QuarterNarrows },
+            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "field.weekday", "\u0430\u043f\u0442\u0430 \u043a\u04af\u043d\u0456" },
+            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
+            { "japanese.QuarterNames", metaValue_QuarterNames },
+            { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
-            { "field.month", "\u0430\u0439" },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "field.second", "\u0441\u0435\u043a\u0443\u043d\u0434" },
             { "roc.MonthNames", metaValue_MonthNames },
             { "field.week", "\u0430\u043f\u0442\u0430" },
-            { "DayAbbreviations", metaValue_DayAbbreviations },
-            { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
-                new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
-                }
-            },
-            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
-            { "calendarname.islamic", "\u0418\u0441\u043b\u0430\u043c \u043a\u04af\u043d\u0442\u0456\u0437\u0431\u0435\u0441\u0456" },
             { "roc.DayNarrows", metaValue_DayNarrows },
-            { "roc.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "{one:0\u00a0\u043c\u044b\u04a3 other:0\u00a0\u043c\u044b\u04a3}",
+                    "{one:00\u00a0\u043c\u044b\u04a3 other:00\u00a0\u043c\u044b\u04a3}",
+                    "{one:000\u00a0\u043c'.' other:000\u00a0\u043c'.'}",
+                    "{one:0\u00a0\u043c\u043b\u043d other:0\u00a0\u043c\u043b\u043d}",
+                    "{one:00\u00a0\u043c\u043b\u043d other:00\u00a0\u043c\u043b\u043d}",
+                    "{one:000\u00a0\u043c\u043b\u043d other:000\u00a0\u043c\u043b\u043d}",
+                    "{one:0\u00a0\u043c\u043b\u0440\u0434 other:0\u00a0\u043c\u043b\u0440\u0434}",
+                    "{one:00\u00a0\u043c\u043b\u0440\u0434 other:00\u00a0\u043c\u043b\u0440\u0434}",
+                    "{one:000\u00a0\u043c\u043b\u0440\u0434 other:000\u00a0\u043c\u043b\u0440\u0434}",
+                    "{one:0\u00a0\u0442\u0440\u043b\u043d other:0\u00a0\u0442\u0440\u043b\u043d}",
+                    "{one:00\u00a0\u0442\u0440\u043b\u043d other:00\u00a0\u0442\u0440\u043b\u043d}",
+                    "{one:000\u00a0\u0442\u0440\u043b\u043d other:000\u00a0\u0442\u0440\u043b\u043d}",
+                }
+            },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "timezone.regionFormat.daylight", "{0} \u0436\u0430\u0437\u0493\u044b \u0443\u0430\u049b\u044b\u0442\u044b" },
             { "DatePatterns",
@@ -304,20 +375,9 @@ public class FormatData_kk extends ListResourceBundle {
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
             { "islamic.TimePatterns", metaValue_TimePatterns },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "standalone.DayNames",
-                new String[] {
-                    "\u0416\u0435\u043a\u0441\u0435\u043d\u0431\u0456",
-                    "\u0414\u04af\u0439\u0441\u0435\u043d\u0431\u0456",
-                    "\u0421\u0435\u0439\u0441\u0435\u043d\u0431\u0456",
-                    "\u0421\u04d9\u0440\u0441\u0435\u043d\u0431\u0456",
-                    "\u0411\u0435\u0439\u0441\u0435\u043d\u0431\u0456",
-                    "\u0416\u04b1\u043c\u0430",
-                    "\u0421\u0435\u043d\u0431\u0456",
-                }
-            },
+            { "standalone.DayNames", metaValue_DayNames },
+            { "PluralRules", "one:n = 1" },
             { "field.hour", "\u0441\u0430\u0493\u0430\u0442" },
-            { "japanese.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
-            { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "calendarname.buddhist", "\u0411\u0443\u0434\u0434\u0430 \u043a\u04af\u043d\u0442\u0456\u0437\u0431\u0435\u0441\u0456" },
             { "standalone.MonthNames",
                 new String[] {
@@ -336,33 +396,20 @@ public class FormatData_kk extends ListResourceBundle {
                     "",
                 }
             },
-            { "standalone.MonthAbbreviations",
+            { "latn.NumberPatterns",
                 new String[] {
-                    "\u049a\u0430\u04a3.",
-                    "\u0410\u049b\u043f.",
-                    "\u041d\u0430\u0443.",
-                    "\u0421\u04d9\u0443.",
-                    "\u041c\u0430\u043c.",
-                    "\u041c\u0430\u0443.",
-                    "\u0428\u0456\u043b.",
-                    "\u0422\u0430\u043c.",
-                    "\u049a\u044b\u0440.",
-                    "\u049a\u0430\u0437.",
-                    "\u049a\u0430\u0440.",
-                    "\u0416\u0435\u043b.",
-                    "",
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a0\u00a4",
                 }
             },
-            { "timezone.regionFormat", "{0} \u0443\u0430\u049b\u044b\u0442\u044b" },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
-            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
-            { "roc.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "standalone.QuarterNames", metaValue_QuarterNames },
-            { "japanese.MonthNarrows", metaValue_MonthNarrows },
+            { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "calendarname.gregory", metaValue_calendarname_gregorian },
         };
         return data;
